@@ -20,11 +20,11 @@ Template::Flute - Modern designer-friendly HTML templating Engine
 
 =head1 VERSION
 
-Version 0.0191
+Version 0.0192
 
 =cut
 
-our $VERSION = '0.0191';
+our $VERSION = '0.0192';
 
 =head1 SYNOPSIS
 
@@ -172,7 +172,7 @@ Specification file name.
 =item specification_parser
 
 Select specification parser. This can be either the full class name
-like L<MyApp::Specification::Parser> or the last part for classes residing
+like C<MyApp::Specification::Parser> or the last part for classes residing
 in the Template::Flute::Specification namespace.
 
 =item specification
@@ -2369,6 +2369,10 @@ L<http://search.cpan.org/dist/Template-Flute/>
 
 =head1 ACKNOWLEDGEMENTS
 
+Thanks to Nitish Bezzala (GH #157).
+
+Thanks to Mohammad S Anwar (GH #156).
+
 Thanks to Paul Cochrane for his tremendous amount of pull requests
 issued during the GitHub challenge.
 
@@ -2398,7 +2402,7 @@ a request from Matt S. Trout, author of the L<HTML::Zoom> module.
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright 2010-2015 Stefan Hornburg (Racke) <racke@linuxia.de>.
+Copyright 2010-2016 Stefan Hornburg (Racke) <racke@linuxia.de>.
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of either: the GNU General Public License as published
